==> eiffelstudio-18.01.10.1424.tar: F_code/C147/rt7321.c <==
/*
 * Code for class RT_DBG_ATTRIBUTE_RECORD [NATURAL_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "rt7321.h"
#include "eif_built_in.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RT_DBG_ATTRIBUTE_RECORD}.object */
EIF_REFERENCE F3640_39764 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {RT_DBG_ATTRIBUTE_RECORD}.value */
EIF_NATURAL_8 F3640_39765 (EIF_REFERENCE Current)
{
	return *(EIF_NATURAL_8 *)(Current+ _CHROFF_2_0_);
}


/* {RT_DBG_ATTRIBUTE_RECORD}.debug_output */
EIF_REFERENCE F3640_39771 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("debug_output", 3639, Current, 0, 0, 46115);
	RTGC;
	RTHOOK(1);
	tr1 = F3604_39722(Current);
	tr2 = RTMS_EX_H(" (object=",9,1677333821);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R36904[Dtype(tr1)-4041])(RTCW(tr1), tr2);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr2 = (EIF_REFERENCE) eif_builtin_ANY_generating_type (tr2);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R34780[Dtype(tr2)-3782])(RTCW(tr2));
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R36904[Dtype(tr1)-4041])(RTCW(tr1), tr2);
	tr2 = RTMS_EX_H(")",1,41);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R36904[Dtype(tr1)-4041])(RTCW(tr1), tr2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {RT_DBG_ATTRIBUTE_RECORD}.to_string */
EIF_REFERENCE F3640_39772 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_NATURAL_8 loc1 = (EIF_NATURAL_8) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_string", 3639, Current, 1, 0, 46116);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_NATURAL_8 *)(Current+ _CHROFF_2_0_);
	RTHOOK(2);
	switch (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_1_0_2_)) {
		case 1L:
			RTHOOK(3);
			if (EIF_TRUE) {
				RTHOOK(4);
				Result = c_outp((EIF_NATURAL_8 *) &(loc1));
			} else {
				RTHOOK(5);
				Result = RTMS_EX_H("Void",4,1450142052);
			}
			break;
		case 7L:
			RTHOOK(6);
			if (EIF_TRUE) {
				RTHOOK(7);
				Result = c_outp((EIF_NATURAL_8 *) &(loc1));
			} else {
				RTHOOK(8);
				tr1 = RTLNS(eif_new_type(4043, 0x00).id, 4043, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F4039_45469(RTCW(tr1));
				Result = (EIF_REFERENCE) tr1;
			}
			break;
		default:
			RTHOOK(9);
			if (EIF_TRUE) {
				RTHOOK(10);
				Result = F3640_39777(Current, loc1);
			} else {
				RTHOOK(11);
				tr1 = RTLNS(eif_new_type(4043, 0x00).id, 4043, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F4039_45469(RTCW(tr1));
				Result = (EIF_REFERENCE) tr1;
			}
			break;
	}
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

/* {RT_DBG_ATTRIBUTE_RECORD}.out_value */
EIF_REFERENCE F3640_39777 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	
	
	RTEAA("out_value", 3639, Current, 0, 1, 46105);
	RTHOOK(1);
	tr1 = c_outu(arg1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit7321 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C147/rt7321.c <==
/*
 * Code for class RT_DBG_FIELD_RECORD [NATURAL_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "rt7321.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RT_DBG_FIELD_RECORD}.value */
EIF_NATURAL_8 F3626_39957 (EIF_REFERENCE Current)
{
	return *(EIF_NATURAL_8 *)(Current+ _CHROFF_2_0_);
}


/* {RT_DBG_FIELD_RECORD}.to_string */
EIF_REFERENCE F3626_39962 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_NATURAL_8 loc1 = (EIF_NATURAL_8) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("to_string", 3625, Current, 1, 0, 45965);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_NATURAL_8 *)(Current+ _CHROFF_2_0_);
	RTHOOK(2);
	switch (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_1_0_1_)) {
		case 1L:
			RTHOOK(3);
			if (EIF_TRUE) {
				RTHOOK(4);
				Result = c_outp((EIF_NATURAL_8 *) &(loc1));
			} else {
				RTHOOK(5);
				Result = RTMS_EX_H("Void",4,1450142052);
			}
			break;
		case 7L:
			RTHOOK(6);
			if (EIF_TRUE) {
				RTHOOK(7);
				Result = c_outp((EIF_NATURAL_8 *) &(loc1));
			} else {
				RTHOOK(8);
				tr1 = RTLNS(eif_new_type(4056, 0x00).id, 4056, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F4048_45693(RTCW(tr1));
				Result = (EIF_REFERENCE) tr1;
			}
			break;
		default:
			RTHOOK(9);
			if (EIF_TRUE) {
				RTHOOK(10);
				Result = F3626_39967(Current, loc1);
			} else {
				RTHOOK(11);
				tr1 = RTLNS(eif_new_type(4056, 0x00).id, 4056, _OBJSIZ_1_1_0_3_0_0_0_0_);
				F4048_45693(RTCW(tr1));
				Result = (EIF_REFERENCE) tr1;
			}
			break;
	}
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

/* {RT_DBG_FIELD_RECORD}.out_value */
EIF_REFERENCE F3626_39967 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	
	
	RTEAA("out_value", 3625, Current, 0, 1, 45970);
	RTHOOK(1);
	tr1 = c_outu(arg1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit7321 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
